**To delete a reference store**

The following ``delete-reference-store`` example deletes a reference store with ID ``1234567890``. ::

    aws omics delete-reference-store \
        --id 1234567890

For more information, see `Omics Storage <https://docs.aws.amazon.com/omics/latest/dev/sequence-stores.html>`__ in the *Amazon Omics Developer Guide*.
